@@ -12,7 +12,7 @@ use File::Temp qw(tempdir);
 use POSIX qw(SIGTERM WNOHANG);
 use Time::HiRes qw(sleep);
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 our $errstr;
 our @SEARCH_PATHS = qw(/usr/local/mysql);
@@ -288,7 +288,7 @@ sub _use_mysqld_initialize {
     my $self = shift;
 
     my $mysqld = $self->mysqld;
-    `$mysqld --verbose --help` =~ /--initialize-insecure/ms;
+    `$mysqld --verbose --help 2>/dev/null` =~ /--initialize-insecure/ms;
 }
 
 sub _get_path_of {
